import sqlite3

version = 1

def create(db_path):
    db = sqlite3.connect(db_path)
    with db:
        db.execute('BEGIN')
        db.execute('''
        CREATE TABLE schedule(
            id    INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
            name  TEXT NOT NULL UNIQUE CHECK (name <> ''),
            start INTEGER NOT NULL,
            stop  INTEGER NOT NULL,
            days  TEXT CHECK (days <> ''))
        ''')
        db.execute('''
        CREATE TABLE recipient_group(
            id         INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
            name       TEXT NOT NULL UNIQUE CHECK (name <> ''),
            recipients TEXT CHECK (recipients <> ''))
        ''')
        db.execute('''
        CREATE TABLE orchid(
            uuid               TEXT NOT NULL PRIMARY KEY CHECK (uuid <> ''),
            recipient_group_id INTEGER REFERENCES recipient_group(id) ON DELETE SET NULL)
        ''')
        db.execute('''
        CREATE TABLE orchid_camera(
            orchid_uuid TEXT NOT NULL REFERENCES orchid(uuid) ON DELETE CASCADE,
            camera_id   INTEGER NOT NULL,
            last_check  INTEGER NOT NULL DEFAULT 0,
            last_email  INTEGER NOT NULL DEFAULT 0,
            PRIMARY KEY(orchid_uuid, camera_id))
        ''')
        db.execute('''
        CREATE TABLE orchid_schedule(
            orchid_uuid TEXT NOT NULL REFERENCES orchid(uuid) ON DELETE CASCADE,
            schedule_id INTEGER NOT NULL REFERENCES schedule(id) ON DELETE CASCADE,
            PRIMARY KEY(orchid_uuid, schedule_id))
        ''')
        db.execute('''
        CREATE TABLE alert(
            orchid_uuid TEXT NOT NULL,
            camera_id   INTEGER NOT NULL,
            timestamp   INTEGER NOT NULL,
            PRIMARY KEY(orchid_uuid, camera_id, timestamp),
            FOREIGN KEY(orchid_uuid, camera_id)
                REFERENCES orchid_camera(orchid_uuid, camera_id)
                ON DELETE CASCADE)
        ''')
        db.execute('''
        CREATE TABLE schema_version(
            version INTEGER NOT NULL PRIMARY KEY)
        ''')
        db.execute('INSERT INTO schema_version VALUES(?)', (version,))
    db.close()
